summaryrefslogtreecommitdiff
path: root/tests/apps
diff options
context:
space:
mode:
Diffstat (limited to 'tests/apps')
-rw-r--r--tests/apps/tests.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/tests/apps/tests.py b/tests/apps/tests.py
index 278caa3584..9f989c5d9a 100644
--- a/tests/apps/tests.py
+++ b/tests/apps/tests.py
@@ -33,20 +33,20 @@ HERE = os.path.dirname(__file__)
class AppsTests(SimpleTestCase):
- def test_singleton_master(self):
+ def test_singleton_main(self):
"""
Only one master registry can exist.
"""
with self.assertRaises(RuntimeError):
Apps(installed_apps=None)
def test_ready(self):
"""
Tests the ready property of the master registry.
"""
# The master app registry is always ready when the tests run.
self.assertIs(apps.ready, True)
# Non-master app registries are populated in __init__.
self.assertIs(Apps().ready, True)
# The condition is set when apps are ready
self.assertIs(apps.ready_event.is_set(), True)
@@ -33,20 +33,20 @@ HERE = os.path.dirname(__file__)
"""
- Only one master registry can exist.
+ Only one main registry can exist.
"""
with self.assertRaises(RuntimeError):
@@ -33,20 +33,20 @@ HERE = os.path.dirname(__file__)
def test_ready(self):
"""
- Tests the ready property of the master registry.
+ Tests the ready property of the main registry.
"""
@@ -33,20 +33,20 @@ HERE = os.path.dirname(__file__)
"""
- # The master app registry is always ready when the tests run.
+ # The main app registry is always ready when the tests run.
self.assertIs(apps.ready, True)
@@ -33,20 +33,20 @@ HERE = os.path.dirname(__file__)
self.assertIs(apps.ready, True)
- # Non-master app registries are populated in __init__.
+ # Non-main app registries are populated in __init__.
self.assertIs(Apps().ready, True)
# The condition is set when apps are ready